:py:mod:`piel.models.frequency.photonic.coupler_simple`
=======================================================

.. py:module:: piel.models.frequency.photonic.coupler_simple


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.coupler_simple.coupler



.. py:function:: coupler(coupling=0.5)
